Biología
Ecosistemas • Sistema Cerrado: No tiene influencias externas, Ejemplo un lago
• Sistema Abierto: Se ve afectado por influencias externas y comparte
materia Ejemplo: Un Árbol
SERES VIVOS MEDIO FÍSICO Tipos: Microecosistema
(Biocenosis) (Abióticos)
Mesoecosistema
Macroecosistema
Poblaciones Factores Limitantes
-Densidad poblacional: N° x unidad de - Clima Artificiales:
volumen ○ Microclima -Urbanos
-Hábitat: Donde viven ○ Mesoclima -Agrícolas
- Suelo
-Nicho: Función que cumplen ○ Fuente de sustancias nutritivas -Piscícolas
-Inmigración: Llegada de nuevos x ○ Sustrato
▪ Arenoso Terrestres:
-Migración: Salida de integrantes ▪ Fértil -Tundra
-Plaga: Población sin sistema de control ▪ Arcilloso -Taiga
-Equilibrio: a mayor población, mayor
mortalidad por depredadores -Bosque templado
-Potencial biótico: Tamaño máximo que -Bosque mediterráneo
puede alcanzar una población -Bosque tropical
-Capacidad de Carga: N° Máximo que puede -Pradera
sostener el ambiente dado -Desierto
-Dispersión: Capacidad para mudarse y
sobrevivir
Tutorías Biolo página 1
, Relaciones
Intraespecíficas: Misma especie Interespecíficas: Diferente especie
-Reproducción: RElación Especie 1 Especie 2
-Positiva Mutualismo + +
-Herencia Facultivo + +
-Selección Natural Comensalismo+ =
-Competencia
Neutralismo = =
-Territorio Parasitismo + -
-Pareja Amensalismo = -
-Comida Competencia - -
❖ Organización Social Depredación + -
-Familiar Ej: Leones Hervivoría + -
-Gregarias: Viajan Juntos Ej: Conceptos nuevos:
Peces
-Coloniales: íntimamente unidos Ej: Mutualismo Se ayudan entre sí ej: pez payaso - anemonas
Corales Facultivo: Se ayudan pero pueden vivir sin la otra
-Sociales: En jerarquía Ej: Abejas
Comensalismo: Una se ayuda de la otra pero no se ve afectada
Neutra: conviven sin lastimarse
Parasitismo: Uno se alimenta de la otra sin matarlo, vive en ella
Amensalismo: Una especie sin verse afectada no permite que otra viva
Flujo de energía
Esto indica un movimiento de materia y energía
• Dentro de esta materia tenemos inerte, orgánica,
Nutrientes
Productores Consumidores Descomponedores
Autótrofos Heterótrofos Heterótrofos
-Plantas - Primarios -Bacterias
-Fotosíntesis ○ Herbívoros
- Secundarios
○ Carnívoros
- Terciarios
○ Carroñeros
Ley de la conservación de la materia
Tutorías Biolo página 2
Ecosistemas • Sistema Cerrado: No tiene influencias externas, Ejemplo un lago
• Sistema Abierto: Se ve afectado por influencias externas y comparte
materia Ejemplo: Un Árbol
SERES VIVOS MEDIO FÍSICO Tipos: Microecosistema
(Biocenosis) (Abióticos)
Mesoecosistema
Macroecosistema
Poblaciones Factores Limitantes
-Densidad poblacional: N° x unidad de - Clima Artificiales:
volumen ○ Microclima -Urbanos
-Hábitat: Donde viven ○ Mesoclima -Agrícolas
- Suelo
-Nicho: Función que cumplen ○ Fuente de sustancias nutritivas -Piscícolas
-Inmigración: Llegada de nuevos x ○ Sustrato
▪ Arenoso Terrestres:
-Migración: Salida de integrantes ▪ Fértil -Tundra
-Plaga: Población sin sistema de control ▪ Arcilloso -Taiga
-Equilibrio: a mayor población, mayor
mortalidad por depredadores -Bosque templado
-Potencial biótico: Tamaño máximo que -Bosque mediterráneo
puede alcanzar una población -Bosque tropical
-Capacidad de Carga: N° Máximo que puede -Pradera
sostener el ambiente dado -Desierto
-Dispersión: Capacidad para mudarse y
sobrevivir
Tutorías Biolo página 1
, Relaciones
Intraespecíficas: Misma especie Interespecíficas: Diferente especie
-Reproducción: RElación Especie 1 Especie 2
-Positiva Mutualismo + +
-Herencia Facultivo + +
-Selección Natural Comensalismo+ =
-Competencia
Neutralismo = =
-Territorio Parasitismo + -
-Pareja Amensalismo = -
-Comida Competencia - -
❖ Organización Social Depredación + -
-Familiar Ej: Leones Hervivoría + -
-Gregarias: Viajan Juntos Ej: Conceptos nuevos:
Peces
-Coloniales: íntimamente unidos Ej: Mutualismo Se ayudan entre sí ej: pez payaso - anemonas
Corales Facultivo: Se ayudan pero pueden vivir sin la otra
-Sociales: En jerarquía Ej: Abejas
Comensalismo: Una se ayuda de la otra pero no se ve afectada
Neutra: conviven sin lastimarse
Parasitismo: Uno se alimenta de la otra sin matarlo, vive en ella
Amensalismo: Una especie sin verse afectada no permite que otra viva
Flujo de energía
Esto indica un movimiento de materia y energía
• Dentro de esta materia tenemos inerte, orgánica,
Nutrientes
Productores Consumidores Descomponedores
Autótrofos Heterótrofos Heterótrofos
-Plantas - Primarios -Bacterias
-Fotosíntesis ○ Herbívoros
- Secundarios
○ Carnívoros
- Terciarios
○ Carroñeros
Ley de la conservación de la materia
Tutorías Biolo página 2